CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
138 lines
4.1 KiB
C++
138 lines
4.1 KiB
C++
/*
|
|
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
*/
|
|
|
|
|
|
#include <hip_test_checkers.hh>
|
|
#include <hip_test_common.hh>
|
|
|
|
/**
|
|
* @addtogroup hipGraphExecNodeSetParams hipGraphExecNodeSetParams
|
|
* @{
|
|
* @ingroup GraphTest
|
|
* `hipGraphExecNodeSetParams(hipGraphExec_t graphExec, hipGraphNode_t node,
|
|
* hipGraphNodeParams *nodeParams)` -
|
|
* Updates parameters of a created node on executable graph
|
|
*/
|
|
|
|
/**
|
|
* Test Description
|
|
* ------------------------
|
|
* - Verify API behavior with invalid arguments:
|
|
* -# gGraphExec is nullptr
|
|
* -# node is nullptr
|
|
* -# nodeParams is nullptr
|
|
* Test source
|
|
* ------------------------
|
|
* - unit/graph/hipGraphExecNodeSetParams.cc
|
|
* Test requirements
|
|
* ------------------------
|
|
* - HIP_VERSION >= 6.4
|
|
*/
|
|
HIP_TEST_CASE(Unit_hipGraphExecNodeSetParams_Negative_Parameters) {
|
|
hipGraph_t graph;
|
|
hipGraphExec_t graphExec;
|
|
hipGraphNode_t node;
|
|
hipGraphNodeParams node_params = {};
|
|
char* A_d;
|
|
size_t Nbytes = 10 * sizeof(char);
|
|
|
|
HIP_CHECK(hipGraphCreate(&graph, 0));
|
|
HIP_CHECK(hipMalloc(&A_d, Nbytes));
|
|
node_params.type = hipGraphNodeTypeMemset;
|
|
node_params.memset.dst = A_d;
|
|
node_params.memset.elementSize = sizeof(char);
|
|
node_params.memset.width = 10;
|
|
node_params.memset.height = 1;
|
|
node_params.memset.pitch = 10;
|
|
node_params.memset.value = 99;
|
|
|
|
HIP_CHECK(hipGraphAddNode(&node, graph, nullptr, 0, &node_params));
|
|
HIP_CHECK(hipGraphInstantiate(&graphExec, graph, nullptr, nullptr, 0));
|
|
HIP_CHECK(hipGraphLaunch(graphExec, 0));
|
|
|
|
SECTION("hGraphExec == nullptr") {
|
|
HIP_CHECK_ERROR(hipGraphExecNodeSetParams(nullptr, node, &node_params), hipErrorInvalidValue);
|
|
}
|
|
|
|
SECTION("node == nullptr") {
|
|
HIP_CHECK_ERROR(hipGraphExecNodeSetParams(graphExec, nullptr, &node_params),
|
|
hipErrorInvalidValue);
|
|
}
|
|
|
|
SECTION("node params == nullptr") {
|
|
HIP_CHECK_ERROR(hipGraphExecNodeSetParams(graphExec, node, nullptr), hipErrorInvalidValue);
|
|
}
|
|
|
|
HIP_CHECK(hipGraphExecDestroy(graphExec));
|
|
HIP_CHECK(hipGraphDestroy(graph));
|
|
HIP_CHECK(hipFree(A_d));
|
|
}
|
|
/**
|
|
* Test Description
|
|
* ------------------------
|
|
* - This will verify the new node param values are successfully
|
|
* copied to graph node, after launching graphExec
|
|
* Test source
|
|
* ------------------------
|
|
* - unit/graph/hipGraphExecNodeSetParams.cc
|
|
* Test requirements
|
|
* ------------------------
|
|
* - HIP_VERSION >= 6.4
|
|
*/
|
|
HIP_TEST_CASE(Unit_hipGraphExecNodeSetParams_Positive) {
|
|
hipGraph_t graph;
|
|
hipGraphExec_t graphExec;
|
|
hipGraphNode_t node;
|
|
hipGraphNodeParams node_params = {};
|
|
char *A_d = nullptr, *A_h = nullptr;
|
|
size_t Nbytes = 10 * sizeof(char);
|
|
|
|
HIP_CHECK(hipGraphCreate(&graph, 0));
|
|
HIP_CHECK(hipMalloc(&A_d, Nbytes));
|
|
node_params.type = hipGraphNodeTypeMemset;
|
|
node_params.memset.dst = A_d;
|
|
node_params.memset.elementSize = sizeof(char);
|
|
node_params.memset.width = 10;
|
|
node_params.memset.height = 1;
|
|
node_params.memset.pitch = 10;
|
|
node_params.memset.value = 99;
|
|
|
|
HIP_CHECK(hipGraphAddNode(&node, graph, nullptr, 0, &node_params));
|
|
HIP_CHECK(hipGraphInstantiate(&graphExec, graph, nullptr, nullptr, 0));
|
|
HIP_CHECK(hipGraphLaunch(graphExec, 0));
|
|
HIP_CHECK(hipStreamSynchronize(0));
|
|
A_h = reinterpret_cast<char*>(malloc(Nbytes));
|
|
HIP_CHECK(hipMemcpy(A_h, A_d, Nbytes, hipMemcpyDeviceToHost));
|
|
for (int i = 0; i < 10; i++) {
|
|
REQUIRE(A_h[i] == 99);
|
|
}
|
|
|
|
hipGraphNodeParams node_params2 = {};
|
|
node_params2.type = hipGraphNodeTypeMemset;
|
|
node_params2.memset.dst = A_d;
|
|
node_params2.memset.elementSize = sizeof(char);
|
|
node_params2.memset.width = 10;
|
|
node_params2.memset.height = 1;
|
|
node_params2.memset.pitch = 10;
|
|
node_params2.memset.value = 110;
|
|
|
|
HIP_CHECK(hipGraphExecNodeSetParams(graphExec, node, &node_params2));
|
|
HIP_CHECK(hipGraphLaunch(graphExec, 0));
|
|
HIP_CHECK(hipStreamSynchronize(0));
|
|
HIP_CHECK(hipMemcpy(A_h, A_d, Nbytes, hipMemcpyDeviceToHost));
|
|
for (int i = 0; i < 10; i++) {
|
|
REQUIRE(A_h[i] == 110);
|
|
}
|
|
HIP_CHECK(hipGraphExecDestroy(graphExec));
|
|
HIP_CHECK(hipGraphDestroy(graph));
|
|
HIP_CHECK(hipFree(A_d));
|
|
free(A_h);
|
|
}
|
|
/**
|
|
* End doxygen group GraphTest.
|
|
* @}
|
|
*/
|